[Buildbot-commits] buildbot/buildbot interfaces.py,1.22,1.23

Brian Warner warner at users.sourceforge.net
Sat Apr 23 20:07:49 UTC 2005


Update of /cvsroot/buildbot/buildbot/buildbot
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv15098/buildbot

Modified Files:
	interfaces.py 
Log Message:
Revision: arch at buildbot.sf.net--2004/buildbot--dev--0--patch-81
Creator:  Brian Warner <warner at monolith.lothar.com>

Merged docs from [org.apestaart at thomas/buildbot--doc--0--patch-9]

Patches applied:

 * org.apestaart at thomas/buildbot--doc--0--patch-8
   more docs

 * org.apestaart at thomas/buildbot--doc--0--patch-9
   fix an accidental indent error on my part


Index: interfaces.py
===================================================================
RCS file: /cvsroot/buildbot/buildbot/buildbot/interfaces.py,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -d -r1.22 -r1.23
--- interfaces.py	18 Apr 2005 00:26:56 -0000	1.22
+++ interfaces.py	23 Apr 2005 20:07:46 -0000	1.23
@@ -154,7 +154,11 @@
     finished."""
 
     def getBuilder():
-        """Return the name of the Builder that ran this build."""
+        """
+        Return the BuilderStatus that ran this build.
+        
+        @rtype: implementor of L{IBuilderStatus}
+        """
 
     def getNumber():
         """Within each builder, each Build has a number. Return it."""
@@ -307,7 +311,7 @@
         may have spaces in it."""
 
     def getBuild():
-        """Returns an IBuildStatus object which contains this step."""
+        """Returns the IBuildStatus object which contains this step."""
 
     def getTimes():
         """Returns a tuple of (start, end). 'start' and 'end' are the times
@@ -499,9 +503,15 @@
     subscribed to an IStatus, an IBuilderStatus, or an IBuildStatus."""
 
     def builderAdded(builderName, builder):
-        """A new Builder has just been added. This method may return an
-        IStatusTarget (probably 'self') which will be subscribed to receive
-        builderChangedState and buildStarted/Finished events."""
+        """
+        A new Builder has just been added. This method may return an
+        IStatusReceiver (probably 'self') which will be subscribed to receive
+        builderChangedState and buildStarted/Finished events.
+
+        @type  builderName: string
+        @type  builder:     L{buildbot.status.builder.BuilderStatus}
+        @rtype: implementor of L{IStatusReceiver}
+        """
 
     def builderChangedState(builderName, state, eta=None):
         """Builder 'builderName' has changed state. The possible values for
@@ -514,13 +524,12 @@
         object which implements IBuildStatus, and can be queried for more
         information.
 
         This method may return an IStatusTarget (it could even return
         'self'). If it does so, stepStarted and stepFinished methods will be
         invoked on the object for the steps of this one build. This is a
-        convenient way to subscribe to all build steps without missing
-        any.
+        convenient way to subscribe to all build steps without missing any.
 
         It can also return a tuple of (IStatusTarget, interval), in which
         case buildETAUpdate messages are sent ever 'interval' seconds, in
         addition to the stepStarted and stepFinished messages."""
 
@@ -532,12 +541,12 @@
         """A step has just started. 'step' is the IBuildStepStatus which
         represents the step: it can be queried for more information.
 
         This method may return an IStatusTarget (it could even return
         'self'). If it does so, logStarted and logFinished methods will be
         invoked on the object for logs created by this one step.
 
-        Alternatively, the method may return a tuple of an IStatusTarget and
-        an integer named 'updateInterval'. In addition to
+        Alternatively, the method may return a tuple of an IStatusReceiver
+        and an integer named 'updateInterval'. In addition to
         logStarted/logFinished messages, it will also receive stepETAUpdate
         messages about every updateInterval seconds."""
 
@@ -553,7 +562,7 @@
         started running a shell command. 'log' is the IStatusLog object
         which can be queried for more information.
 
         This method may return an IStatusTarget (such as 'self'), in which
         case the target's logChunk method will be invoked as text is added to
         the logfile. """
 
@@ -569,8 +578,14 @@
         in IBuildStepStatus.getResults."""
 
     def buildFinished(builderName, build, results):
-        """A build has just finished. 'results' is the result tuple described
-        in IBuildStatus.getResults."""
+        """
+        A build has just finished. 'results' is the result tuple described
+        in L{IBuildStatus.getResults}.
+
+        @type  builderName: string
+        @type  build:       L{buildbot.status.builder.BuildStatus}
+        @type  results:     tuple
+        """
 
     def builderRemoved(builderName):
         """The Builder has been removed."""
@@ -514,13 +524,12 @@
         information.
 
-        This method may return an IStatusTarget (it could even return
+        This method may return an IStatusReceiver (it could even return
         'self'). If it does so, stepStarted and stepFinished methods will be
         invoked on the object for the steps of this one build. This is a
@@ -514,13 +524,12 @@
 
-        It can also return a tuple of (IStatusTarget, interval), in which
+        It can also return a tuple of (IStatusReceiver, interval), in which
         case buildETAUpdate messages are sent ever 'interval' seconds, in
         addition to the stepStarted and stepFinished messages."""
@@ -532,12 +541,12 @@
         represents the step: it can be queried for more information.
 
-        This method may return an IStatusTarget (it could even return
+        This method may return an IStatusReceiver (it could even return
         'self'). If it does so, logStarted and logFinished methods will be
         invoked on the object for logs created by this one step.
@@ -553,7 +562,7 @@
         which can be queried for more information.
 
-        This method may return an IStatusTarget (such as 'self'), in which
+        This method may return an IStatusReceiver (such as 'self'), in which
         case the target's logChunk method will be invoked as text is added to
         the logfile. """





More information about the Commits mailing list